@@ -24,37 +24,42 @@
 #include "bakery/bakery.h"
 #include "frame_glom.h"
 
-
 class App_Glom : public Bakery::App_WithDoc_Gtk
 {
 public:
   App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   virtual ~App_Glom();
 
-  virtual void init(const Glib::ustring& document_uri = Glib::ustring()); //override
+  virtual bool init(const Glib::ustring& document_uri = Glib::ustring()); //override
 
-  virtual void statusbar_set_text(const Glib::ustring& strText);
-  virtual void statusbar_clear();
+  //virtual void statusbar_set_text(const Glib::ustring& strText);
+  //virtual void statusbar_clear();
 
   /// Get the UIManager so we can merge new menus in.
   Glib::RefPtr<Gtk::UIManager> get_ui_manager();
 
-  virtual void on_database_selected(bool database_selected);
-
   /** Changes the mode to Data mode, as if the user had selected the Data Mode menu item.
    */
-  virtual void set_mode_data();
+  void set_mode_data();
+  void set_mode_find();
+
+  void add_developer_action(const Glib::RefPtr<Gtk::Action>& refAction);
+  void remove_developer_action(const Glib::RefPtr<Gtk::Action>& refAction);
+
+  AppState::userlevels get_userlevel() const;
+
+  void update_userlevel_ui();
 
-  virtual AppState::userlevels get_userlevel() const;
-    
 protected:
   virtual void init_layout(); //override.
+  virtual void init_menus_file(); //override.
   virtual void init_menus(); //override.
   virtual void init_menus_help(); //override
+  virtual void init_toolbars(); //override
   virtual void init_create_document(); //override
-  virtual void on_document_load(); //override.
+  virtual bool on_document_load(); //override.
 
-  virtual void offer_new_or_existing();
+  virtual bool offer_new_or_existing();
 
   virtual void on_menu_help_contents();
   virtual void on_menu_userlevel_developer();
@@ -64,6 +69,8 @@ protected:
 
   virtual Bakery::App* new_instance(); //Override
 
+  virtual bool recreate_database(bool& user_cancelled); //return indicates success.
+  
   typedef Bakery::App_WithDoc_Gtk type_base;
 
   //Widgets:
@@ -72,8 +79,7 @@ protected:
 
   typedef std::list< Glib::RefPtr<Gtk::Action> > type_listActions; 
   type_listActions m_listDeveloperActions; //Only enabled when in developer mode.
-  type_listActions m_listWithDatabaseActions;  //Only enabled when a database has been selected.
-  Glib::RefPtr<Gtk::Action> m_action_mode_data;
+  Glib::RefPtr<Gtk::Action> m_action_mode_data, m_action_mode_find;
   Glib::RefPtr<Gtk::RadioAction> m_action_menu_userlevel_developer, m_action_menu_userlevel_operator;
   
   Gtk::VBox* m_pBoxTop;
