@@ -43,7 +43,7 @@ Box_Data_List::Box_Data_List()
     }
   }
 
-  m_strHint = _("When you change the data in a field the database is updated immediately.\n Click [Add] or enter data into the last row to add a new record.\n Leave automatic ID fields empty - they will be filled for you.\nOnly the first 100 records are shown.");
+  //m_strHint = _("When you change the data in a field the database is updated immediately.\n Click [Add] or enter data into the last row to add a new record.\n Leave automatic ID fields empty - they will be filled for you.\nOnly the first 100 records are shown.");
 
   pack_start(m_AddDel);
   add_view(&m_AddDel); //Give it access to the document.
@@ -72,8 +72,10 @@ Box_Data_List::~Box_Data_List()
   remove_view(&m_AddDel);
 }
 
-void Box_Data_List::fill_from_database()
+bool Box_Data_List::fill_from_database()
 {
+  bool result = false;
+
   Bakery::BusyCursor(*get_app_window());
 
   try
@@ -100,6 +102,8 @@ void Box_Data_List::fill_from_database()
 
     m_AddDel.set_where_clause(m_strWhereClause);
 
+    result = m_AddDel.refresh_from_database();
+
     if(table_privs.m_view)
     {
       //TODO: Don't show it if m_view is false.
@@ -112,12 +116,14 @@ void Box_Data_List::fill_from_database()
     } //privs
 
     fill_end();
-
   }
   catch(std::exception& ex)
   {
     handle_error(ex);
+    result = false;
   }
+
+  return result;
 }
 
 void Box_Data_List::on_adddel_user_requested_add()
@@ -423,12 +429,17 @@ void Box_Data_List::refresh_related_fields(const Gtk::TreeModel::iterator& row,
 
     Glib::RefPtr<Gnome::Gda::DataModel> result = Query_execute(query);
     if(!result)
+    {
+      g_warning("Box_Data_List::refresh_related_fields(): no result.");
       handle_error();
+    }
     else
     {
       //Field contents:
       if(result->get_n_rows())
       {
+        g_warning("Box_Data_List::refresh_related_fields(): records_count=%d", result->get_n_rows());
+
         type_vecLayoutFields::const_iterator iterFields = fieldsToGet.begin();
 
         guint cols_count = result->get_n_columns();
@@ -446,6 +457,8 @@ void Box_Data_List::refresh_related_fields(const Gtk::TreeModel::iterator& row,
           ++iterFields;
         }
       }
+      else
+       g_warning("Box_Data_List::refresh_related_fields(): no records found.");
     }
   }
 }
